ImageSetLayer
=============

.. currentmodule:: wwt_data_formats.layers

.. autoclass:: ImageSetLayer
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ImageSetLayer.cross_validation_lock
      ~ImageSetLayer.extension
      ~ImageSetLayer.id
      ~ImageSetLayer.image_set
      ~ImageSetLayer.layer_type
      ~ImageSetLayer.name
      ~ImageSetLayer.opacity
      ~ImageSetLayer.override_default
      ~ImageSetLayer.reference_frame
      ~ImageSetLayer.rmeta

   .. rubric:: Methods Summary

   .. autosummary::

      ~ImageSetLayer.add_traits
      ~ImageSetLayer.apply_to_xml
      ~ImageSetLayer.class_own_trait_events
      ~ImageSetLayer.class_own_traits
      ~ImageSetLayer.class_trait_names
      ~ImageSetLayer.class_traits
      ~ImageSetLayer.from_file
      ~ImageSetLayer.from_text
      ~ImageSetLayer.from_url
      ~ImageSetLayer.from_xml
      ~ImageSetLayer.has_trait
      ~ImageSetLayer.hold_trait_notifications
      ~ImageSetLayer.notify_change
      ~ImageSetLayer.observe
      ~ImageSetLayer.on_trait_change
      ~ImageSetLayer.set_trait
      ~ImageSetLayer.setup_instance
      ~ImageSetLayer.to_xml
      ~ImageSetLayer.to_xml_string
      ~ImageSetLayer.trait_defaults
      ~ImageSetLayer.trait_events
      ~ImageSetLayer.trait_has_value
      ~ImageSetLayer.trait_metadata
      ~ImageSetLayer.trait_names
      ~ImageSetLayer.trait_values
      ~ImageSetLayer.traits
      ~ImageSetLayer.unobserve
      ~ImageSetLayer.unobserve_all
      ~ImageSetLayer.write_xml

   .. rubric:: Attributes Documentation

   .. autoattribute:: cross_validation_lock
   .. autoattribute:: extension
   .. autoattribute:: id
   .. autoattribute:: image_set
   .. autoattribute:: layer_type
   .. autoattribute:: name
   .. autoattribute:: opacity
   .. autoattribute:: override_default
   .. autoattribute:: reference_frame
   .. autoattribute:: rmeta

   .. rubric:: Methods Documentation

   .. automethod:: add_traits
   .. automethod:: apply_to_xml
   .. automethod:: class_own_trait_events
   .. automethod:: class_own_traits
   .. automethod:: class_trait_names
   .. automethod:: class_traits
   .. automethod:: from_file
   .. automethod:: from_text
   .. automethod:: from_url
   .. automethod:: from_xml
   .. automethod:: has_trait
   .. automethod:: hold_trait_notifications
   .. automethod:: notify_change
   .. automethod:: observe
   .. automethod:: on_trait_change
   .. automethod:: set_trait
   .. automethod:: setup_instance
   .. automethod:: to_xml
   .. automethod:: to_xml_string
   .. automethod:: trait_defaults
   .. automethod:: trait_events
   .. automethod:: trait_has_value
   .. automethod:: trait_metadata
   .. automethod:: trait_names
   .. automethod:: trait_values
   .. automethod:: traits
   .. automethod:: unobserve
   .. automethod:: unobserve_all
   .. automethod:: write_xml
